--==============================================================
-- DBMS name:      ANSI Level 2
-- Created on:     12.12.2005 09:41:37
-- Modified on:	   17.10.2007 10:56:44
--==============================================================

--==============================================================
-- Database: WIBE 
--==============================================================
use wibe;

--==============================================================
-- Table: BENUTZER
--==============================================================
create table BENUTZER (
BENUTZERID           INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ANMELDENAME          VARCHAR(30)          not null,
KENNWORT             VARCHAR(50)          not null,
VORNAME              VARCHAR(30),
NACHNAME             VARCHAR(30),
ISTWIBEBEAUFTRAGTER  CHAR(1)              not null,
ISTPROJEKTLEITER     CHAR(1)              not null,
ISTCONTROLLER        CHAR(1)              not null,
ISTKATALOGAUTOR      CHAR(1)              not null,
primary key (BENUTZERID)
);

--==============================================================
-- Index: X_ANMELDENAME
--==============================================================
create unique index X_ANMELDENAME on BENUTZER (
ANMELDENAME ASC
);

--==============================================================
-- Table: FORMELN
--==============================================================
create table FORMELN (
FORMELID             INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
FORMEL               VARCHAR(50)          not null,
primary key (FORMELID)
);

--==============================================================
-- Table: INFORMATIONSTEILE
--==============================================================
create table INFORMATIONSTEILE (
INFORMATIONSTEILID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
INFORMATIONID        INTEGER              not null,
NUMMER               INTEGER              not null,
TEXT                 VARCHAR(250)         not null,
primary key (INFORMATIONSTEILID)
);

--==============================================================
-- Index: X_INFORMATIONSTEILNUMMER
--==============================================================
create unique index X_INFORMATIONSTEILNUMMER on INFORMATIONSTEILE (
INFORMATIONID ASC,
NUMMER ASC
);

--==============================================================
-- Table: KATALOGE
--==============================================================
create table KATALOGE (
KATALOGID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
NAME                 VARCHAR(50)          not null,
BEZEICHNUNG          VARCHAR(50),
AUTOR                VARCHAR(30),
KOMMENTAR            VARCHAR(255),
KAPITALWERTNAME      VARCHAR(30),
KAPITALWERTBEZEICHNUNG VARCHAR(50),
TEILKAPITALWERTHWNAME VARCHAR(30),
TEILKAPITALWERTHWBEZEICHNUNG VARCHAR(50),
TEILKAPITALWERTNHNAME VARCHAR(30),
TEILKAPITALWERTNHBEZEICHNUNG VARCHAR(50),
RISIKONAME           VARCHAR(30),
RISIKOBEZEICHNUNG    VARCHAR(50),
primary key (KATALOGID)
);

--==============================================================
-- Index: X_KATALOGNAME
--==============================================================
create unique index X_KATALOGNAME on KATALOGE (
NAME ASC
);

--==============================================================
-- Table: NOTIZEN
--==============================================================
create table NOTIZEN (
NOTIZID              INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (NOTIZID)
);

--==============================================================
-- Table: NOTIZENTEILE
--==============================================================
create table NOTIZENTEILE (
NOTIZID              INTEGER              not null,
TEILID               INTEGER              not null,
TEXT                 VARCHAR(250)         not null,
primary key (NOTIZID, TEILID)
);

--==============================================================
-- Table: PROJEKTE
--==============================================================
create table PROJEKTE (
PROJEKTID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
NAME                 VARCHAR(30)          not null,
BEZEICHNUNG          VARCHAR(50),
ANLAGEDATUM          DATE,
STARTDATUM           DATE                 not null,
ENDEDATUM            DATE                 not null,
BASISJAHR            INTEGER              not null,
NUTZUNGSDAUER        INTEGER              not null,
BERECHNUNGSJAHRE     INTEGER              not null,
ZINSSATZ             DECIMAL (6,3)        not null,
ISTABZINSUNG         CHAR(1)              not null,
PROJEKTLEITER        VARCHAR(30),
BEARBEITER           VARCHAR(30),
NOTIZID              INTEGER,
AKTUELLEVERSIONID    INTEGER              not null,
primary key (PROJEKTID)
);

--==============================================================
-- Index: X_PROJEKTNAME
--==============================================================
create unique index X_PROJEKTNAME on PROJEKTE (
NAME ASC
);

--==============================================================
-- Table: RECHENBLAETTER
--==============================================================
create table RECHENBLAETTER (
RECHENBLATTID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (RECHENBLATTID)
);

--==============================================================
-- Table: RECHENBLATTZEILEN
--==============================================================
create table RECHENBLATTZEILEN (
RECHENBLATTID        INTEGER              not null,
ZEILENNUMMER         INTEGER              not null,
BEZEICHNUNG          VARCHAR(50),
primary key (RECHENBLATTID, ZEILENNUMMER)
);

--==============================================================
-- Table: RECHENBLATTZELLEN
--==============================================================
create table RECHENBLATTZELLEN (
RECHENBLATTID        INTEGER              not null,
ZEILENNUMMER         INTEGER              not null,
JAHR                 INTEGER              not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
ANZAHL               DECIMAL(4,2)         not null,
primary key (RECHENBLATTID, ZEILENNUMMER, JAHR)
);

--==============================================================
-- Table: RICHTWERTTABELLEN
--==============================================================
create table RICHTWERTTABELLEN (
RICHTWERTTABELLENID  INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
NAME                 VARCHAR(30)          not null,
STARTJAHR            INTEGER              not null,
ENDJAHR              INTEGER              not null,
primary key (RICHTWERTTABELLENID)
);

--==============================================================
-- Index: X_RICHTWERTTABELLENNAME
--==============================================================
create unique index X_RICHTWERTTABELLENNAME on RICHTWERTTABELLEN (
NAME ASC
);

--==============================================================
-- Table: TECHNISCHE_IDS
--==============================================================
create table TECHNISCHE_IDS (
ID                   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
TABELLE              VARCHAR(30)          not null,
primary key (ID)
);

--==============================================================
-- Table: VERSIONEN
--==============================================================
create table VERSIONEN (
VERSIONID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
PROJEKTID            INTEGER              not null,
NUMMER               INTEGER              not null,
NAME                 VARCHAR(30)          not null,
ISTGESPERRT          CHAR(1)              not null,
NOTIZID              INTEGER,
AKTUELLEALTERNATIVEID INTEGER              not null,
primary key (VERSIONID)
);

--==============================================================
-- Index: X_PROJEKTVERSION
--==============================================================
create unique index X_PROJEKTVERSION on VERSIONEN (
PROJEKTID ASC,
NAME ASC
);

--==============================================================
-- Table: PROJEKTATTRIBUTE
--==============================================================
create table PROJEKTATTRIBUTE (
PROJEKTATTRIBUTID    INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
PROJEKTID            INTEGER              not null,
NAME                 VARCHAR(40)          not null,
WERT                 VARCHAR(255),
primary key (PROJEKTATTRIBUTID)
);

--==============================================================
-- Index: X_ATTRIBUTNAME
--==============================================================
create unique index X_ATTRIBUTNAME on PROJEKTATTRIBUTE (
PROJEKTID ASC,
NAME ASC
);

--==============================================================
-- Table: ALTERNATIVEN
--==============================================================
create table ALTERNATIVEN (
ALTERNATIVEID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
VERSIONID            INTEGER              not null,
NUMMER               INTEGER              not null,
NAME                 VARCHAR(30)          not null,
ISTGESPERRT          CHAR(1)              not null,
NOTIZID              INTEGER,
primary key (ALTERNATIVEID)
);

--==============================================================
-- Index: X_ALTERNATIVENNAME
--==============================================================
create unique index X_ALTERNATIVENNAME on ALTERNATIVEN (
VERSIONID ASC,
NAME ASC
);

--==============================================================
-- Table: MITARBEITER
--==============================================================
create table MITARBEITER (
MITARBEITERID        INTEGER              not null,
PROJEKTID            INTEGER              not null,
BENUTZERID           INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (MITARBEITERID)
);

--==============================================================
-- Index: X_MITARBEITER
--==============================================================
create unique index X_MITARBEITER on MITARBEITER (
PROJEKTID ASC,
BENUTZERID ASC
);

--==============================================================
-- Table: RICHTWERTE
--==============================================================
create table RICHTWERTE (
RICHTWERTID          INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
RICHTWERTTABELLENID  INTEGER              not null,
BEZEICHNUNG          VARCHAR(50)          not null,
primary key (RICHTWERTID)
);

--==============================================================
-- Table: GRUPPEN
--==============================================================
create table GRUPPEN (
GRUPPEID             INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
OBERGRUPPEID         INTEGER,
BEWERTUNGSTYP        INTEGER              not null,
ISTHAUPTGRUPPE       CHAR(1)              not null,
REIHENFOLGE          INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
INFORMATIONID        INTEGER,
KENNWERTNAME         VARCHAR(30),
KENNWERTBEZEICHNUNG  VARCHAR(50),
primary key (GRUPPEID)
);

--==============================================================
-- Index: X_GRUPPENREIHENFOLGE
--==============================================================
create unique index X_GRUPPENREIHENFOLGE on GRUPPEN (
OBERGRUPPEID ASC,
REIHENFOLGE ASC
);

--==============================================================
-- Index: X_GRUPPENNAME
--==============================================================
create  index X_GRUPPENNAME on GRUPPEN (
KATALOGID ASC,
BEZEICHNUNG ASC
);

--==============================================================
-- Table: KRITERIEN
--==============================================================
create table KRITERIEN (
KRITERIUMID          INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
GRUPPEID             INTEGER              not null,
BEWERTUNGSTYP        INTEGER              not null,
REIHENFOLGE          INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
INFORMATIONID        INTEGER,
GEWICHT              INTEGER,
ISTKOSTENKRITERIUM   CHAR(1),
RICHTWERTTABELLENID  INTEGER,
primary key (KRITERIUMID)
);

--==============================================================
-- Index: X_KRITERIENREIHENFOLGE
--==============================================================
create unique index X_KRITERIENREIHENFOLGE on KRITERIEN (
GRUPPEID ASC,
REIHENFOLGE ASC
);

--==============================================================
-- Index: X_KRITERIENNAME
--==============================================================
create  index X_KRITERIENNAME on KRITERIEN (
KATALOGID ASC,
BEZEICHNUNG ASC
);

--==============================================================
-- Table: OPTIONSTEXTE
--==============================================================
create table OPTIONSTEXTE (
OPTIONSTEXTID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KRITERIUMID          INTEGER              not null,
FAKTOR               INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
primary key (OPTIONSTEXTID)
);

--==============================================================
-- Index: X_OPTIONSTEXTBEWERTUNG
--==============================================================
create unique index X_OPTIONSTEXTBEWERTUNG on OPTIONSTEXTE (
KRITERIUMID ASC,
FAKTOR ASC
);

--==============================================================
-- Table: RICHTWERTBETRAEGE
--==============================================================
create table RICHTWERTBETRAEGE (
RICHTWERTBETRAGSID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
RICHTWERTTABELLENID  INTEGER              not null,
RICHTWERTID          INTEGER              not null,
JAHR                 INTEGER              not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
primary key (RICHTWERTBETRAGSID)
);

--==============================================================
-- Table: PROJEKTKRITERIEN
--==============================================================
create table PROJEKTKRITERIEN (
PROJEKTKRITERIUMID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ALTERNATIVEID        INTEGER              not null,
KRITERIUMID          INTEGER              not null,
NOTIZID              INTEGER,
RECHENBLATTID        INTEGER,
BEWERTUNGSTYP        INTEGER              not null,
primary key (PROJEKTKRITERIUMID)
);

--==============================================================
-- Index: X_KATALOGKRITERIUM
--==============================================================
create unique index X_KATALOGKRITERIUM on PROJEKTKRITERIEN (
ALTERNATIVEID ASC,
KRITERIUMID ASC
);

--==============================================================
-- Table: MONETAEREBEWERTUNGEN
--==============================================================
create table MONETAEREBEWERTUNGEN (
PROJEKTKRITERIUMID   INTEGER              not null,
JAHR                 INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
FORMELHWID           INTEGER,
FORMELNHID           INTEGER,
RISIKOHW             DECIMAL(6,3)         not null,
RISIKONH             DECIMAL(6,3)         not null,
primary key (PROJEKTKRITERIUMID, JAHR)
);

--==============================================================
-- Table: ANALYSEN
--==============================================================
create table ANALYSEN (
ANALYSEID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
NAME                 VARCHAR(30)          not null,
BEZEICHNUNG          VARCHAR(50),
STARTACHSEX          DECIMAL(12,2)        not null,
STARTACHSEY          DECIMAL(12,2)        not null,
KENNWERTNAMEX        VARCHAR(30),
KENNWERTGRUPPEIDX    INTEGER,
KENNWERTNAMEY        VARCHAR(30),
KENNWERTGRUPPEIDY    INTEGER,
primary key (ANALYSEID)
);

--==============================================================
-- Index: X_ANALYSENAMEN
--==============================================================
create unique index X_ANALYSENAMEN on ANALYSEN (
NAME ASC
);

--==============================================================
-- Table: QUALITATIVEBEWERTUNGEN
--==============================================================
create table QUALITATIVEBEWERTUNGEN (
PROJEKTKRITERIUMID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
WERT                 INTEGER              not null,
primary key (PROJEKTKRITERIUMID)
);

--==============================================================
-- Table: ANALYSEELEMENTE
--==============================================================
create table ANALYSEELEMENTE (
ANALYSEELEMENTID     INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ANALYSEID            INTEGER              not null,
ALTERNATIVEID        INTEGER              not null,
ROT                  INTEGER,
GRUEN                INTEGER,
BLAU                 INTEGER,
primary key (ANALYSEELEMENTID)
);

--==============================================================
-- Index: X_ANALYSE_ALTERNATIVE
--==============================================================
create unique index X_ANALYSE_ALTERNATIVE on ANALYSEELEMENTE (
ALTERNATIVEID ASC,
ANALYSEID ASC
);

--==============================================================
-- DBMS name:      ANSI Level 2
-- Created on:     12.12.2005 09:41:37
-- Modified on:	   20.03.2008 15:01:44
--==============================================================

--==============================================================
-- Database: WiBe_Abt_01 
--==============================================================
CREATE DATABASE IF NOT EXISTS WiBe_Abt_01;

use WiBe_Abt_01;

--==============================================================
-- Table: BENUTZER
--==============================================================
create table BENUTZER (
BENUTZERID           INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ANMELDENAME          VARCHAR(30)          not null,
KENNWORT             VARCHAR(50)          not null,
VORNAME              VARCHAR(30),
NACHNAME             VARCHAR(30),
ISTWIBEBEAUFTRAGTER  CHAR(1)              not null,
ISTPROJEKTLEITER     CHAR(1)              not null,
ISTCONTROLLER        CHAR(1)              not null,
ISTKATALOGAUTOR      CHAR(1)              not null,
primary key (BENUTZERID)
);

--==============================================================
-- Index: X_ANMELDENAME
--==============================================================
create unique index X_ANMELDENAME on BENUTZER (
ANMELDENAME ASC
);

--==============================================================
-- Table: FORMELN
--==============================================================
create table FORMELN (
FORMELID             INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
FORMEL               VARCHAR(50)          not null,
primary key (FORMELID)
);

--==============================================================
-- Table: INFORMATIONSTEILE
--==============================================================
create table INFORMATIONSTEILE (
INFORMATIONSTEILID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
INFORMATIONID        INTEGER              not null,
NUMMER               INTEGER              not null,
TEXT                 VARCHAR(250)         not null,
primary key (INFORMATIONSTEILID)
);

--==============================================================
-- Index: X_INFORMATIONSTEILNUMMER
--==============================================================
create unique index X_INFORMATIONSTEILNUMMER on INFORMATIONSTEILE (
INFORMATIONID ASC,
NUMMER ASC
);

--==============================================================
-- Table: KATALOGE
--==============================================================
create table KATALOGE (
KATALOGID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
NAME                 VARCHAR(50)          not null,
BEZEICHNUNG          VARCHAR(50),
AUTOR                VARCHAR(30),
KOMMENTAR            VARCHAR(255),
KAPITALWERTNAME      VARCHAR(30),
KAPITALWERTBEZEICHNUNG VARCHAR(50),
TEILKAPITALWERTHWNAME VARCHAR(30),
TEILKAPITALWERTHWBEZEICHNUNG VARCHAR(50),
TEILKAPITALWERTNHNAME VARCHAR(30),
TEILKAPITALWERTNHBEZEICHNUNG VARCHAR(50),
RISIKONAME           VARCHAR(30),
RISIKOBEZEICHNUNG    VARCHAR(50),
primary key (KATALOGID)
);

--==============================================================
-- Index: X_KATALOGNAME
--==============================================================
create unique index X_KATALOGNAME on KATALOGE (
NAME ASC
);

--==============================================================
-- Table: NOTIZEN
--==============================================================
create table NOTIZEN (
NOTIZID              INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (NOTIZID)
);

--==============================================================
-- Table: NOTIZENTEILE
--==============================================================
create table NOTIZENTEILE (
NOTIZID              INTEGER              not null,
TEILID               INTEGER              not null,
TEXT                 VARCHAR(250)         not null,
primary key (NOTIZID, TEILID)
);

--==============================================================
-- Table: PROJEKTE
--==============================================================
create table PROJEKTE (
PROJEKTID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
NAME                 VARCHAR(30)          not null,
BEZEICHNUNG          VARCHAR(50),
ANLAGEDATUM          DATE,
STARTDATUM           DATE                 not null,
ENDEDATUM            DATE                 not null,
BASISJAHR            INTEGER              not null,
NUTZUNGSDAUER        INTEGER              not null,
BERECHNUNGSJAHRE     INTEGER              not null,
ZINSSATZ             DECIMAL (6,3)        not null,
ISTABZINSUNG         CHAR(1)              not null,
PROJEKTLEITER        VARCHAR(30),
BEARBEITER           VARCHAR(30),
NOTIZID              INTEGER,
AKTUELLEVERSIONID    INTEGER              not null,
primary key (PROJEKTID)
);

--==============================================================
-- Index: X_PROJEKTNAME
--==============================================================
create unique index X_PROJEKTNAME on PROJEKTE (
NAME ASC
);

--==============================================================
-- Table: RECHENBLAETTER
--==============================================================
create table RECHENBLAETTER (
RECHENBLATTID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (RECHENBLATTID)
);

--==============================================================
-- Table: RECHENBLATTZEILEN
--==============================================================
create table RECHENBLATTZEILEN (
RECHENBLATTID        INTEGER              not null,
ZEILENNUMMER         INTEGER              not null,
BEZEICHNUNG          VARCHAR(50),
primary key (RECHENBLATTID, ZEILENNUMMER)
);

--==============================================================
-- Table: RECHENBLATTZELLEN
--==============================================================
create table RECHENBLATTZELLEN (
RECHENBLATTID        INTEGER              not null,
ZEILENNUMMER         INTEGER              not null,
JAHR                 INTEGER              not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
ANZAHL               DECIMAL(4,2)         not null,
primary key (RECHENBLATTID, ZEILENNUMMER, JAHR)
);

--==============================================================
-- Table: RICHTWERTTABELLEN
--==============================================================
create table RICHTWERTTABELLEN (
RICHTWERTTABELLENID  INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
NAME                 VARCHAR(30)          not null,
STARTJAHR            INTEGER              not null,
ENDJAHR              INTEGER              not null,
primary key (RICHTWERTTABELLENID)
);

--==============================================================
-- Index: X_RICHTWERTTABELLENNAME
--==============================================================
create unique index X_RICHTWERTTABELLENNAME on RICHTWERTTABELLEN (
NAME ASC
);

--==============================================================
-- Table: TECHNISCHE_IDS
--==============================================================
create table TECHNISCHE_IDS (
ID                   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
TABELLE              VARCHAR(30)          not null,
primary key (ID)
);

--==============================================================
-- Table: VERSIONEN
--==============================================================
create table VERSIONEN (
VERSIONID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
PROJEKTID            INTEGER              not null,
NUMMER               INTEGER              not null,
NAME                 VARCHAR(30)          not null,
ISTGESPERRT          CHAR(1)              not null,
NOTIZID              INTEGER,
AKTUELLEALTERNATIVEID INTEGER              not null,
primary key (VERSIONID)
);

--==============================================================
-- Index: X_PROJEKTVERSION
--==============================================================
create unique index X_PROJEKTVERSION on VERSIONEN (
PROJEKTID ASC,
NAME ASC
);

--==============================================================
-- Table: PROJEKTATTRIBUTE
--==============================================================
create table PROJEKTATTRIBUTE (
PROJEKTATTRIBUTID    INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
PROJEKTID            INTEGER              not null,
NAME                 VARCHAR(40)          not null,
WERT                 VARCHAR(255),
primary key (PROJEKTATTRIBUTID)
);

--==============================================================
-- Index: X_ATTRIBUTNAME
--==============================================================
create unique index X_ATTRIBUTNAME on PROJEKTATTRIBUTE (
PROJEKTID ASC,
NAME ASC
);

--==============================================================
-- Table: ALTERNATIVEN
--==============================================================
create table ALTERNATIVEN (
ALTERNATIVEID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
VERSIONID            INTEGER              not null,
NUMMER               INTEGER              not null,
NAME                 VARCHAR(30)          not null,
ISTGESPERRT          CHAR(1)              not null,
NOTIZID              INTEGER,
primary key (ALTERNATIVEID)
);

--==============================================================
-- Index: X_ALTERNATIVENNAME
--==============================================================
create unique index X_ALTERNATIVENNAME on ALTERNATIVEN (
VERSIONID ASC,
NAME ASC
);

--==============================================================
-- Table: MITARBEITER
--==============================================================
create table MITARBEITER (
MITARBEITERID        INTEGER              not null,
PROJEKTID            INTEGER              not null,
BENUTZERID           INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (MITARBEITERID)
);

--==============================================================
-- Index: X_MITARBEITER
--==============================================================
create unique index X_MITARBEITER on MITARBEITER (
PROJEKTID ASC,
BENUTZERID ASC
);

--==============================================================
-- Table: RICHTWERTE
--==============================================================
create table RICHTWERTE (
RICHTWERTID          INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
RICHTWERTTABELLENID  INTEGER              not null,
BEZEICHNUNG          VARCHAR(50)          not null,
primary key (RICHTWERTID)
);

--==============================================================
-- Table: GRUPPEN
--==============================================================
create table GRUPPEN (
GRUPPEID             INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
OBERGRUPPEID         INTEGER,
BEWERTUNGSTYP        INTEGER              not null,
ISTHAUPTGRUPPE       CHAR(1)              not null,
REIHENFOLGE          INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
INFORMATIONID        INTEGER,
KENNWERTNAME         VARCHAR(30),
KENNWERTBEZEICHNUNG  VARCHAR(50),
primary key (GRUPPEID)
);

--==============================================================
-- Index: X_GRUPPENREIHENFOLGE
--==============================================================
create unique index X_GRUPPENREIHENFOLGE on GRUPPEN (
OBERGRUPPEID ASC,
REIHENFOLGE ASC
);

--==============================================================
-- Index: X_GRUPPENNAME
--==============================================================
create  index X_GRUPPENNAME on GRUPPEN (
KATALOGID ASC,
BEZEICHNUNG ASC
);

--==============================================================
-- Table: KRITERIEN
--==============================================================
create table KRITERIEN (
KRITERIUMID          INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
GRUPPEID             INTEGER              not null,
BEWERTUNGSTYP        INTEGER              not null,
REIHENFOLGE          INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
INFORMATIONID        INTEGER,
GEWICHT              INTEGER,
ISTKOSTENKRITERIUM   CHAR(1),
RICHTWERTTABELLENID  INTEGER,
primary key (KRITERIUMID)
);

--==============================================================
-- Index: X_KRITERIENREIHENFOLGE
--==============================================================
create unique index X_KRITERIENREIHENFOLGE on KRITERIEN (
GRUPPEID ASC,
REIHENFOLGE ASC
);

--==============================================================
-- Index: X_KRITERIENNAME
--==============================================================
create  index X_KRITERIENNAME on KRITERIEN (
KATALOGID ASC,
BEZEICHNUNG ASC
);

--==============================================================
-- Table: OPTIONSTEXTE
--==============================================================
create table OPTIONSTEXTE (
OPTIONSTEXTID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KRITERIUMID          INTEGER              not null,
FAKTOR               INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
primary key (OPTIONSTEXTID)
);

--==============================================================
-- Index: X_OPTIONSTEXTBEWERTUNG
--==============================================================
create unique index X_OPTIONSTEXTBEWERTUNG on OPTIONSTEXTE (
KRITERIUMID ASC,
FAKTOR ASC
);

--==============================================================
-- Table: RICHTWERTBETRAEGE
--==============================================================
create table RICHTWERTBETRAEGE (
RICHTWERTBETRAGSID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
RICHTWERTTABELLENID  INTEGER              not null,
RICHTWERTID          INTEGER              not null,
JAHR                 INTEGER              not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
primary key (RICHTWERTBETRAGSID)
);

--==============================================================
-- Table: PROJEKTKRITERIEN
--==============================================================
create table PROJEKTKRITERIEN (
PROJEKTKRITERIUMID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ALTERNATIVEID        INTEGER              not null,
KRITERIUMID          INTEGER              not null,
NOTIZID              INTEGER,
RECHENBLATTID        INTEGER,
BEWERTUNGSTYP        INTEGER              not null,
primary key (PROJEKTKRITERIUMID)
);

--==============================================================
-- Index: X_KATALOGKRITERIUM
--==============================================================
create unique index X_KATALOGKRITERIUM on PROJEKTKRITERIEN (
ALTERNATIVEID ASC,
KRITERIUMID ASC
);

--==============================================================
-- Table: MONETAEREBEWERTUNGEN
--==============================================================
create table MONETAEREBEWERTUNGEN (
PROJEKTKRITERIUMID   INTEGER              not null,
JAHR                 INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
FORMELHWID           INTEGER,
FORMELNHID           INTEGER,
RISIKOHW             DECIMAL(6,3)         not null,
RISIKONH             DECIMAL(6,3)         not null,
primary key (PROJEKTKRITERIUMID, JAHR)
);

--==============================================================
-- Table: ANALYSEN
--==============================================================
create table ANALYSEN (
ANALYSEID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
NAME                 VARCHAR(30)          not null,
BEZEICHNUNG          VARCHAR(50),
STARTACHSEX          DECIMAL(12,2)        not null,
STARTACHSEY          DECIMAL(12,2)        not null,
KENNWERTNAMEX        VARCHAR(30),
KENNWERTGRUPPEIDX    INTEGER,
KENNWERTNAMEY        VARCHAR(30),
KENNWERTGRUPPEIDY    INTEGER,
primary key (ANALYSEID)
);

--==============================================================
-- Index: X_ANALYSENAMEN
--==============================================================
create unique index X_ANALYSENAMEN on ANALYSEN (
NAME ASC
);

--==============================================================
-- Table: QUALITATIVEBEWERTUNGEN
--==============================================================
create table QUALITATIVEBEWERTUNGEN (
PROJEKTKRITERIUMID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
WERT                 INTEGER              not null,
primary key (PROJEKTKRITERIUMID)
);

--==============================================================
-- Table: ANALYSEELEMENTE
--==============================================================
create table ANALYSEELEMENTE (
ANALYSEELEMENTID     INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ANALYSEID            INTEGER              not null,
ALTERNATIVEID        INTEGER              not null,
ROT                  INTEGER,
GRUEN                INTEGER,
BLAU                 INTEGER,
primary key (ANALYSEELEMENTID)
);

--==============================================================
-- Index: X_ANALYSE_ALTERNATIVE
--==============================================================
create unique index X_ANALYSE_ALTERNATIVE on ANALYSEELEMENTE (
ALTERNATIVEID ASC,
ANALYSEID ASC
);

--==============================================================
-- Database: WiBe_Abt_02 
--==============================================================
CREATE DATABASE IF NOT EXISTS WiBe_Abt_02;

use WiBe_Abt_02;

--==============================================================
-- Table: BENUTZER
--==============================================================
create table BENUTZER (
BENUTZERID           INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ANMELDENAME          VARCHAR(30)          not null,
KENNWORT             VARCHAR(50)          not null,
VORNAME              VARCHAR(30),
NACHNAME             VARCHAR(30),
ISTWIBEBEAUFTRAGTER  CHAR(1)              not null,
ISTPROJEKTLEITER     CHAR(1)              not null,
ISTCONTROLLER        CHAR(1)              not null,
ISTKATALOGAUTOR      CHAR(1)              not null,
primary key (BENUTZERID)
);

--==============================================================
-- Index: X_ANMELDENAME
--==============================================================
create unique index X_ANMELDENAME on BENUTZER (
ANMELDENAME ASC
);

--==============================================================
-- Table: FORMELN
--==============================================================
create table FORMELN (
FORMELID             INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
FORMEL               VARCHAR(50)          not null,
primary key (FORMELID)
);

--==============================================================
-- Table: INFORMATIONSTEILE
--==============================================================
create table INFORMATIONSTEILE (
INFORMATIONSTEILID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
INFORMATIONID        INTEGER              not null,
NUMMER               INTEGER              not null,
TEXT                 VARCHAR(250)         not null,
primary key (INFORMATIONSTEILID)
);

--==============================================================
-- Index: X_INFORMATIONSTEILNUMMER
--==============================================================
create unique index X_INFORMATIONSTEILNUMMER on INFORMATIONSTEILE (
INFORMATIONID ASC,
NUMMER ASC
);

--==============================================================
-- Table: KATALOGE
--==============================================================
create table KATALOGE (
KATALOGID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
NAME                 VARCHAR(50)          not null,
BEZEICHNUNG          VARCHAR(50),
AUTOR                VARCHAR(30),
KOMMENTAR            VARCHAR(255),
KAPITALWERTNAME      VARCHAR(30),
KAPITALWERTBEZEICHNUNG VARCHAR(50),
TEILKAPITALWERTHWNAME VARCHAR(30),
TEILKAPITALWERTHWBEZEICHNUNG VARCHAR(50),
TEILKAPITALWERTNHNAME VARCHAR(30),
TEILKAPITALWERTNHBEZEICHNUNG VARCHAR(50),
RISIKONAME           VARCHAR(30),
RISIKOBEZEICHNUNG    VARCHAR(50),
primary key (KATALOGID)
);

--==============================================================
-- Index: X_KATALOGNAME
--==============================================================
create unique index X_KATALOGNAME on KATALOGE (
NAME ASC
);

--==============================================================
-- Table: NOTIZEN
--==============================================================
create table NOTIZEN (
NOTIZID              INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (NOTIZID)
);

--==============================================================
-- Table: NOTIZENTEILE
--==============================================================
create table NOTIZENTEILE (
NOTIZID              INTEGER              not null,
TEILID               INTEGER              not null,
TEXT                 VARCHAR(250)         not null,
primary key (NOTIZID, TEILID)
);

--==============================================================
-- Table: PROJEKTE
--==============================================================
create table PROJEKTE (
PROJEKTID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
NAME                 VARCHAR(30)          not null,
BEZEICHNUNG          VARCHAR(50),
ANLAGEDATUM          DATE,
STARTDATUM           DATE                 not null,
ENDEDATUM            DATE                 not null,
BASISJAHR            INTEGER              not null,
NUTZUNGSDAUER        INTEGER              not null,
BERECHNUNGSJAHRE     INTEGER              not null,
ZINSSATZ             DECIMAL (6,3)        not null,
ISTABZINSUNG         CHAR(1)              not null,
PROJEKTLEITER        VARCHAR(30),
BEARBEITER           VARCHAR(30),
NOTIZID              INTEGER,
AKTUELLEVERSIONID    INTEGER              not null,
primary key (PROJEKTID)
);

--==============================================================
-- Index: X_PROJEKTNAME
--==============================================================
create unique index X_PROJEKTNAME on PROJEKTE (
NAME ASC
);

--==============================================================
-- Table: RECHENBLAETTER
--==============================================================
create table RECHENBLAETTER (
RECHENBLATTID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (RECHENBLATTID)
);

--==============================================================
-- Table: RECHENBLATTZEILEN
--==============================================================
create table RECHENBLATTZEILEN (
RECHENBLATTID        INTEGER              not null,
ZEILENNUMMER         INTEGER              not null,
BEZEICHNUNG          VARCHAR(50),
primary key (RECHENBLATTID, ZEILENNUMMER)
);

--==============================================================
-- Table: RECHENBLATTZELLEN
--==============================================================
create table RECHENBLATTZELLEN (
RECHENBLATTID        INTEGER              not null,
ZEILENNUMMER         INTEGER              not null,
JAHR                 INTEGER              not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
ANZAHL               DECIMAL(4,2)         not null,
primary key (RECHENBLATTID, ZEILENNUMMER, JAHR)
);

--==============================================================
-- Table: RICHTWERTTABELLEN
--==============================================================
create table RICHTWERTTABELLEN (
RICHTWERTTABELLENID  INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
NAME                 VARCHAR(30)          not null,
STARTJAHR            INTEGER              not null,
ENDJAHR              INTEGER              not null,
primary key (RICHTWERTTABELLENID)
);

--==============================================================
-- Index: X_RICHTWERTTABELLENNAME
--==============================================================
create unique index X_RICHTWERTTABELLENNAME on RICHTWERTTABELLEN (
NAME ASC
);

--==============================================================
-- Table: TECHNISCHE_IDS
--==============================================================
create table TECHNISCHE_IDS (
ID                   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
TABELLE              VARCHAR(30)          not null,
primary key (ID)
);

--==============================================================
-- Table: VERSIONEN
--==============================================================
create table VERSIONEN (
VERSIONID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
PROJEKTID            INTEGER              not null,
NUMMER               INTEGER              not null,
NAME                 VARCHAR(30)          not null,
ISTGESPERRT          CHAR(1)              not null,
NOTIZID              INTEGER,
AKTUELLEALTERNATIVEID INTEGER              not null,
primary key (VERSIONID)
);

--==============================================================
-- Index: X_PROJEKTVERSION
--==============================================================
create unique index X_PROJEKTVERSION on VERSIONEN (
PROJEKTID ASC,
NAME ASC
);

--==============================================================
-- Table: PROJEKTATTRIBUTE
--==============================================================
create table PROJEKTATTRIBUTE (
PROJEKTATTRIBUTID    INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
PROJEKTID            INTEGER              not null,
NAME                 VARCHAR(40)          not null,
WERT                 VARCHAR(255),
primary key (PROJEKTATTRIBUTID)
);

--==============================================================
-- Index: X_ATTRIBUTNAME
--==============================================================
create unique index X_ATTRIBUTNAME on PROJEKTATTRIBUTE (
PROJEKTID ASC,
NAME ASC
);

--==============================================================
-- Table: ALTERNATIVEN
--==============================================================
create table ALTERNATIVEN (
ALTERNATIVEID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
VERSIONID            INTEGER              not null,
NUMMER               INTEGER              not null,
NAME                 VARCHAR(30)          not null,
ISTGESPERRT          CHAR(1)              not null,
NOTIZID              INTEGER,
primary key (ALTERNATIVEID)
);

--==============================================================
-- Index: X_ALTERNATIVENNAME
--==============================================================
create unique index X_ALTERNATIVENNAME on ALTERNATIVEN (
VERSIONID ASC,
NAME ASC
);

--==============================================================
-- Table: MITARBEITER
--==============================================================
create table MITARBEITER (
MITARBEITERID        INTEGER              not null,
PROJEKTID            INTEGER              not null,
BENUTZERID           INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
primary key (MITARBEITERID)
);

--==============================================================
-- Index: X_MITARBEITER
--==============================================================
create unique index X_MITARBEITER on MITARBEITER (
PROJEKTID ASC,
BENUTZERID ASC
);

--==============================================================
-- Table: RICHTWERTE
--==============================================================
create table RICHTWERTE (
RICHTWERTID          INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
RICHTWERTTABELLENID  INTEGER              not null,
BEZEICHNUNG          VARCHAR(50)          not null,
primary key (RICHTWERTID)
);

--==============================================================
-- Table: GRUPPEN
--==============================================================
create table GRUPPEN (
GRUPPEID             INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
OBERGRUPPEID         INTEGER,
BEWERTUNGSTYP        INTEGER              not null,
ISTHAUPTGRUPPE       CHAR(1)              not null,
REIHENFOLGE          INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
INFORMATIONID        INTEGER,
KENNWERTNAME         VARCHAR(30),
KENNWERTBEZEICHNUNG  VARCHAR(50),
primary key (GRUPPEID)
);

--==============================================================
-- Index: X_GRUPPENREIHENFOLGE
--==============================================================
create unique index X_GRUPPENREIHENFOLGE on GRUPPEN (
OBERGRUPPEID ASC,
REIHENFOLGE ASC
);

--==============================================================
-- Index: X_GRUPPENNAME
--==============================================================
create  index X_GRUPPENNAME on GRUPPEN (
KATALOGID ASC,
BEZEICHNUNG ASC
);

--==============================================================
-- Table: KRITERIEN
--==============================================================
create table KRITERIEN (
KRITERIUMID          INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
GRUPPEID             INTEGER              not null,
BEWERTUNGSTYP        INTEGER              not null,
REIHENFOLGE          INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
INFORMATIONID        INTEGER,
GEWICHT              INTEGER,
ISTKOSTENKRITERIUM   CHAR(1),
RICHTWERTTABELLENID  INTEGER,
primary key (KRITERIUMID)
);

--==============================================================
-- Index: X_KRITERIENREIHENFOLGE
--==============================================================
create unique index X_KRITERIENREIHENFOLGE on KRITERIEN (
GRUPPEID ASC,
REIHENFOLGE ASC
);

--==============================================================
-- Index: X_KRITERIENNAME
--==============================================================
create  index X_KRITERIENNAME on KRITERIEN (
KATALOGID ASC,
BEZEICHNUNG ASC
);

--==============================================================
-- Table: OPTIONSTEXTE
--==============================================================
create table OPTIONSTEXTE (
OPTIONSTEXTID        INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KRITERIUMID          INTEGER              not null,
FAKTOR               INTEGER              not null,
BEZEICHNUNG          VARCHAR(255),
primary key (OPTIONSTEXTID)
);

--==============================================================
-- Index: X_OPTIONSTEXTBEWERTUNG
--==============================================================
create unique index X_OPTIONSTEXTBEWERTUNG on OPTIONSTEXTE (
KRITERIUMID ASC,
FAKTOR ASC
);

--==============================================================
-- Table: RICHTWERTBETRAEGE
--==============================================================
create table RICHTWERTBETRAEGE (
RICHTWERTBETRAGSID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
RICHTWERTTABELLENID  INTEGER              not null,
RICHTWERTID          INTEGER              not null,
JAHR                 INTEGER              not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
primary key (RICHTWERTBETRAGSID)
);

--==============================================================
-- Table: PROJEKTKRITERIEN
--==============================================================
create table PROJEKTKRITERIEN (
PROJEKTKRITERIUMID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ALTERNATIVEID        INTEGER              not null,
KRITERIUMID          INTEGER              not null,
NOTIZID              INTEGER,
RECHENBLATTID        INTEGER,
BEWERTUNGSTYP        INTEGER              not null,
primary key (PROJEKTKRITERIUMID)
);

--==============================================================
-- Index: X_KATALOGKRITERIUM
--==============================================================
create unique index X_KATALOGKRITERIUM on PROJEKTKRITERIEN (
ALTERNATIVEID ASC,
KRITERIUMID ASC
);

--==============================================================
-- Table: MONETAEREBEWERTUNGEN
--==============================================================
create table MONETAEREBEWERTUNGEN (
PROJEKTKRITERIUMID   INTEGER              not null,
JAHR                 INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
BETRAGHW             DECIMAL(12,2)        not null,
BETRAGNH             DECIMAL(12,2)        not null,
FORMELHWID           INTEGER,
FORMELNHID           INTEGER,
RISIKOHW             DECIMAL(6,3)         not null,
RISIKONH             DECIMAL(6,3)         not null,
primary key (PROJEKTKRITERIUMID, JAHR)
);

--==============================================================
-- Table: ANALYSEN
--==============================================================
create table ANALYSEN (
ANALYSEID            INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
KATALOGID            INTEGER              not null,
NAME                 VARCHAR(30)          not null,
BEZEICHNUNG          VARCHAR(50),
STARTACHSEX          DECIMAL(12,2)        not null,
STARTACHSEY          DECIMAL(12,2)        not null,
KENNWERTNAMEX        VARCHAR(30),
KENNWERTGRUPPEIDX    INTEGER,
KENNWERTNAMEY        VARCHAR(30),
KENNWERTGRUPPEIDY    INTEGER,
primary key (ANALYSEID)
);

--==============================================================
-- Index: X_ANALYSENAMEN
--==============================================================
create unique index X_ANALYSENAMEN on ANALYSEN (
NAME ASC
);

--==============================================================
-- Table: QUALITATIVEBEWERTUNGEN
--==============================================================
create table QUALITATIVEBEWERTUNGEN (
PROJEKTKRITERIUMID   INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
WERT                 INTEGER              not null,
primary key (PROJEKTKRITERIUMID)
);

--==============================================================
-- Table: ANALYSEELEMENTE
--==============================================================
create table ANALYSEELEMENTE (
ANALYSEELEMENTID     INTEGER              not null,
AENDERUNGSZEIT       TIMESTAMP(14)            not null,
ANALYSEID            INTEGER              not null,
ALTERNATIVEID        INTEGER              not null,
ROT                  INTEGER,
GRUEN                INTEGER,
BLAU                 INTEGER,
primary key (ANALYSEELEMENTID)
);

--==============================================================
-- Index: X_ANALYSE_ALTERNATIVE
--==============================================================
create unique index X_ANALYSE_ALTERNATIVE on ANALYSEELEMENTE (
ALTERNATIVEID ASC,
ANALYSEID ASC
);

